@@ -69,23 +69,25 @@ static int superio_ioctl(
 /****** variables ******/
 static const char _szMyName[] = "superio";
 static const char _szImName[] = "superio_do";
-static const char _szMyVersion[] = "3.0";
+static const char _szMyVersion[] = "4.0";
 static const char _szProcfile[] = "driver/thinkpad/superio";
 static word _wPortIndex, _wPortData;
 static struct resource *_presourceSuperio;
 
+#ifdef MODULE
 MODULE_AUTHOR( "Thomas Hood" );
 MODULE_DESCRIPTION( "Driver for the Super I/O chip on IBM ThinkPads" );
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,10)
 MODULE_LICENSE( "GPL" );
 #endif
+#endif
 
 #ifdef CONFIG_DEVFS_FS
 static struct file_operations _fileopsSuperio = {
-	ioctl: superio_ioctl,
-	open: superio_open,
-	release: superio_release,
-	owner: THIS_MODULE
+	.ioctl   = superio_ioctl,
+	.open    = superio_open,
+	.release = superio_release,
+	.owner   = THIS_MODULE
 };
 
 static devfs_handle_t _devfs_handleSuperio;
@@ -103,10 +105,10 @@ static byte getregb( byte bWhere )
 	byte bGot;
 	unsigned long flags;
 
-	save_flags( flags ); cli();
+	local_irq_save( flags );
 	outb_p( bWhere, _wPortIndex );
 	bGot = inb( _wPortData );
-	restore_flags( flags );
+	local_irq_restore( flags );
 
 	return bGot;
 }
@@ -116,10 +118,10 @@ static void putregb( byte bWhat, byte bWhere )
 {
 	unsigned long flags;
 
-	save_flags( flags ); cli();
+	local_irq_save( flags );
 	outb_p( bWhere, _wPortIndex );
 	outb( bWhat, _wPortData );
-	restore_flags( flags );
+	local_irq_restore( flags );
 
 	return;
 }
@@ -221,10 +223,10 @@ static flag_t is_in_pnp_mode( word wPortIndex, word wPortData )
 	byte bGot;
 	unsigned long flags;
 
-	save_flags( flags ); cli();
+	local_irq_save( flags );
 	outb_p( 0x1b, wPortIndex );
 	bGot = inb( wPortData );
-	restore_flags( flags );
+	local_irq_restore( flags );
 
 	return (flag_t)( (bGot >> 3) & 1 );
 }
@@ -846,7 +848,7 @@ static flag_t a_super_io_chip_appears_to_be_at( word wPort )
 	byte bSave, bID;
 	unsigned long flags;
 
-	save_flags( flags ); cli();
+	local_irq_save( flags );
 
 	bSave = inb( wPort );
 
@@ -870,12 +872,12 @@ static flag_t a_super_io_chip_appears_to_be_at( word wPort )
 
 /* Yes: */
 	/* No need to restore index port's contents */
-	restore_flags( flags );
+	local_irq_restore( flags );
 	return 1;
 
 No:
 	outb( bSave, wPort ); /* restore the port's contents */
-	restore_flags( flags );
+	local_irq_restore( flags );
 	return 0;
 }
 
